package com.jeeplus.test.reimbursementsys.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.common.collect.Lists;
import com.jeeplus.aop.demo.annotation.DemoMode;
import com.jeeplus.aop.logging.annotation.ApiLog;
import com.jeeplus.sys.utils.StringUtils;
import com.jeeplus.test.reimbursementsys.domain.dto.ReimbursementBusinessDTO;
import com.jeeplus.test.reimbursementsys.domain.dto.ReimbursementUserDTO;
import com.jeeplus.test.reimbursementsys.service.ReimbursementUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @author 徐滕
 * @version 1.0.0
 * @ClassName ReimbursementUserController.java
 * @Description TODO 报销人员年份金额信息
 * @createTime 2022年05月16日 10:35:21
 */
@RestController
@RequestMapping("/reimbursementUser")
public class ReimbursementUserController {

    @Autowired
    private ReimbursementUserService service;

    /**
     * 根据id报销人员信息
     * @param id
     * @return
     */
    @ApiLog("根据id报销人员信息")
    @PreAuthorize("hasAnyAuthority('reimbursementUser:view','reimbursementUser:add','reimbursementUser:edit')")
    @GetMapping("queryById")
    public ResponseEntity queryById(@RequestParam String id) {
        ReimbursementUserDTO reimbursementDTO = service.queryById (id);
        return ResponseEntity.ok (reimbursementDTO);
    }


    /**
     * 查询报销信息
     * @return
     */
    @ApiLog("查询报销人员信息列表")
    @GetMapping("findList")
    public ResponseEntity findList(ReimbursementUserDTO reimbursementUser, Page<ReimbursementUserDTO> page) {
        IPage<ReimbursementUserDTO> list = service.findList(page,reimbursementUser);
        return ResponseEntity.ok(list);
    }

    /**
     * 保存业务报销编码
     * @return
     */
    @ApiLog("保存报销人员信息")
    @PostMapping("save")
    public ResponseEntity save(@RequestBody ReimbursementUserDTO reimbursementUser) {
        Map<String, Object> result = service.save(reimbursementUser);
        Boolean success = (Boolean) result.get("success");
        if(success){
            return ResponseEntity.ok(result.get("message"));
        }
        return ResponseEntity.badRequest ().body (result.get("message"));
    }

    /**
     * 批量删除
     * @param ids
     * @return
     */
    @DemoMode
    @ApiLog("批量删除")
    @PreAuthorize("hasAuthority('reimbursementUser:del')")
    @DeleteMapping("delete")
    public ResponseEntity delete(String ids) {
        String idArray[] =ids.split(",");
        service.delete ( Lists.newArrayList (idArray) );
        return ResponseEntity.ok ("删除成功！");
    }



    /**
     * 查询报销信息
     * @return
     */
    @ApiLog("查询业务报销信息列表")
    @PreAuthorize("hasAuthority('reimbursementBusiness:view')")
    @GetMapping("findListByUserId")
    public ResponseEntity findListByUserId(String id) {
        if(StringUtils.isBlank(id)){
            return ResponseEntity.badRequest ().body ("请先选择报销人员信息");
        }

        //根据id查询人员填报的报销信息
        ReimbursementUserDTO reimbursementUserDTO = service.queryById(id);
        if(null == reimbursementUserDTO){
            return ResponseEntity.badRequest ().body ("报销人员信息无效，请重新选择");
        }
        List<ReimbursementBusinessDTO> list = service.findListByUserId(reimbursementUserDTO);
        return ResponseEntity.ok(list);
    }
}
