package com.jeeplus.test.reimbursementsys.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.sys.service.dto.UserDTO;
import com.jeeplus.sys.utils.StringUtils;
import com.jeeplus.sys.utils.UserUtils;
import com.jeeplus.test.reimbursementsys.domain.dto.ReimbursementBusinessDTO;
import com.jeeplus.test.reimbursementsys.domain.dto.ReimbursementUserDTO;
import com.jeeplus.test.reimbursementsys.mapper.ReimbursementBusinessMapper;
import com.jeeplus.test.reimbursementsys.mapper.ReimbursementUserMapper;
import com.jeeplus.test.reimbursementsys.service.ReimbursementUserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author li-peike
 * @version 1.0.0
 * @ClassName ReimbursementSysServiceImpl.java
 * @Description TODO
 * @createTime 2022年05月06日 10:38:00
 */
@Service
public class ReimbursementUserServiceImpl implements ReimbursementUserService {

    @Resource
    private ReimbursementUserMapper mapper;

    @Resource
    private ReimbursementBusinessMapper businessMapper;


    @Override
    public ReimbursementUserDTO queryById(String id) {
        return mapper.queryById(id);
    }

    @Override
    public ReimbursementUserDTO queryByUserIdAndYear(ReimbursementUserDTO reimbursementUser) {
        return mapper.queryByUserIdAndYear(reimbursementUser);
    }


    @Override
    public IPage<ReimbursementUserDTO> findList(Page<ReimbursementUserDTO> page, ReimbursementUserDTO reimbursementUser) {
        return mapper.findList (page, reimbursementUser);
    }

    /**
     * 保存
     * @param reimbursementUser
     */
    @Override
    public Map<String,Object> save(ReimbursementUserDTO reimbursementUser) {
        Map<String,Object> map = new HashMap<>();

        if(StringUtils.isBlank(reimbursementUser.getUserId())){
            map.put("success", false);
            map.put("message", "报销人员为空，无法进行添加报销信息!");
            return map;
        }
        if(StringUtils.isBlank(reimbursementUser.getYear())){
            map.put("success", false);
            map.put("message", "报销年份不正确，请重新填写!");
            return map;
        }
        if(StringUtils.isBlank(reimbursementUser.getReimbursementQuota())){
            map.put("success", false);
            map.put("message", "年报销额度填写不正确!");
            return map;
        }
        if(StringUtils.isBlank(reimbursementUser.getReimbursementQuotaDay())){
            map.put("success", false);
            map.put("message", "日报销额度填写不正确!");
            return map;
        }
        UserDTO user = UserUtils.get(reimbursementUser.getUserId());
        if(StringUtils.isNotBlank(reimbursementUser.getId())){
            reimbursementUser.preUpdate();
            //新增
            mapper.update(reimbursementUser);
        }else{
            //查询该用户该年度是否已经添加报销额度
            ReimbursementUserDTO queryByUserIdAndYear = mapper.queryByUserIdAndYear(reimbursementUser);
            if(null != queryByUserIdAndYear){
                map.put("success", false);
                map.put("message", user.getName() + " " + reimbursementUser.getYear() + "年度报销额度已添加，无法重复添加！");
                return map;
            }
            reimbursementUser.preInsert();
            //新增
            mapper.save(reimbursementUser);
        }

        map.put("success", true);
        map.put("message", user.getName() + " " + reimbursementUser.getYear() + "年度报销额度：" + reimbursementUser.getReimbursementQuota() +" 保存成功");
        return map;
    }


    @Override
    public void update(ReimbursementUserDTO reimbursementUser) {
        mapper.update(reimbursementUser);
    }

    @Override
    public void delete(List<String> idList) {
        //删除发票信息
        mapper.delete(idList);
    }

    @Override
    public List<ReimbursementBusinessDTO> findListByUserId(ReimbursementUserDTO reimbursementUserDTO) {
        ReimbursementBusinessDTO reimbursementBusiness = new ReimbursementBusinessDTO();
        reimbursementBusiness.setUserId(reimbursementUserDTO.getUserId());
        reimbursementBusiness.setYear(reimbursementUserDTO.getYear());
        return businessMapper.findListByUserIdAndYear(reimbursementBusiness);
    }

}
